@@ -1,6 +1,7 @@
 import console.utils
 from colorama import Fore
 from console import *
+from arcade import *
 
 class color():
     def inf(information):
@@ -40,6 +41,19 @@ class cons():
         pass
     pass
 
+class arcade_mixed():
+    def render():
+        start_render()
+        pass
+
+    def set_bc(color):
+        set_background_color(color)
+        pass
+
+    def d_circle_o(x,y,radius,color,b_width=1,ta=0,ns=-1):
+        draw_circle_outline(x,y,radius,color,b_width,ta,ns)
+    pass
+
 if __name__ == '__main__':
     color.inf('test')
     pass
